#!/bin/bash

#This script shows how the mapping was done, for quantification of host-derived reads, and reads mapped/unmapped to the gut microbiota database. Quality-filtered paired-end reads are first mapped against the gut microbiota database, unmapped reads are then mapped against the host genomes. Fastq-files are extracted with samtools/picard tools.

declare -a names=(
    AmAi01
    AmAi02
    AmAi03
    #etc
)

for i in ${names[@]};do
	#Names of quality-filtered paired-end reads (assumed to be present in the run directory)
    R1=$i"_paired_R1.fastq.gz"
    R2=$i"_paired_R2.fastq.gz"
    PREFIX=$i
    #Map to honey bee gut microbiota database (see "databases" directory for details). Filter sam-file for unmapped reads, sam-to-bam
    bwa mem -t 20 /databases/honeybee_gut_microbiota_db $R1 $R2 > $PREFIX".sam"
    echo "Sam-to-bam and filtering: $PREFIX"
    samtools view  -h -@10 $PREFIX".sam" | perl filter_sam_aln_length_unmapped.pl - > $PREFIX"_filt.sam"
    samtools view -bh $PREFIX"_filt.sam" | samtools sort - > $PREFIX"_filt_sorted.bam"
    samtools index  $PREFIX"_filt_sorted.bam"
    rm $R1
    rm $R2
    rm *sam
    #Extract all reads not  mapped to the gut microbiota database
    R1_FILT1=$PREFIX"_non_gut_db_R1.fastq"
    R2_FILT1=$PREFIX"_non_gut_db_R2.fastq"
    java -Xmx2g -jar picard.jar SamToFastq I=$PREFIX"_filt_sorted.bam" F=$R1_FILT1 F2=$R2_FILT1 VALIDATION_STRINGENCY=SILENT
    #Map the extracted reads to the host genome db (see "databases" directory for details). Filter sam-file for unmapped reads, sam-to-bam
    bwa mem -t 20 /databases/host_db $R1_FILT1 $R2_FILT1 > $PREFIX"_vs_apis.sam"
    samtools view -bS -@20 $PREFIX"_vs_apis.sam" | samtools sort -@20 - > $PREFIX"_vs_apis_sorted.bam"
    samtools view -h -f 4 -b -@20 $PREFIX"_vs_apis_sorted.bam" | samtools sort - > $PREFIX"_unmapped_sorted.bam"
    #Extract all remaining un-mapped reads (not mapped to current gut microbiota db or host db)
    R1_FILT2=$PREFIX"_all_unmapped_R1.fastq"
    R2_FILT2=$PREFIX"_all_unmapped_R2.fastq"
    java -Xmx2g -jar picard.jar SamToFastq I=$PREFIX"_unmapped_sorted.bam" F=$R1_FILT2 F2=$R2_FILT2 VALIDATION_STRINGENCY=SILENT
    rm *sam
    rm *bam
    rm *bai
done
